import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

enum InputType { all, numeric }

class TextInputDialog extends StatefulWidget {
  final String title;
  final InputType inputType;

  TextInputDialog({@required this.title, this.inputType = InputType.all});

  @override
  State<StatefulWidget> createState() {
    return _TextInputDialogState();
  }
}

class _TextInputDialogState extends State<TextInputDialog> {
  String input = "";
  bool _shifted = true;

  @override
  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(25),
      ),
      elevation: 10.0,
      backgroundColor: Colors.black38,
      titlePadding: EdgeInsets.all(0),
      insetPadding: EdgeInsets.all(0),
      contentPadding: EdgeInsets.all(1),
      content: dialogContent(context),
    );
  }

  dialogContent(BuildContext context) {
    return GestureDetector(
        onTap: () {
          FocusScope.of(context).requestFocus(new FocusNode());
        },
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: Center(
                child: Text(
                  "Insert " + widget.title.toUpperCase(),
                  textAlign: TextAlign.center,
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
            Column(
              children: <Widget>[
                Container(
                    color: Colors.white24,
                    margin: EdgeInsets.symmetric(vertical: 25),
                    child: Row(
                      children: <Widget>[
                        Spacer(),
                        Center(
                          child: Text(
                            input,
                            textAlign: TextAlign.center,
                            style: TextStyle(fontSize: 30, color: Colors.white),
                          ),
                        ),
                        Spacer(),
                      ],
                    )),
                widget.inputType == InputType.all ? _buildAlphabets() : _buildNumpad(),
                ButtonBar(
                  alignment: MainAxisAlignment.spaceAround,
                  children: <Widget>[
                    RaisedButton(
                      padding: EdgeInsets.symmetric(vertical: 10),
                      shape: RoundedRectangleBorder(
                        borderRadius: new BorderRadius.circular(10.0),
                      ),
                      color: Colors.grey,
                      child: Container(
                          width: MediaQuery.of(context).size.width * 0.3,
                          child: Center(
                              child: Text(
                            "Cancel",
                            style: TextStyle(color: Colors.white),
                          ))),
                      onPressed: () {
                        Navigator.pop(context);
                      },
                    ),
                    RaisedButton(
                      padding: EdgeInsets.symmetric(vertical: 10),
                      shape: RoundedRectangleBorder(
                        borderRadius: new BorderRadius.circular(10.0),
                      ),
                      color: Colors.grey,
                      child: Container(
                          width: MediaQuery.of(context).size.width * 0.3,
                          child: Center(
                              child: Text(
                            "Confirm".toUpperCase(),
                            style: TextStyle(
                              color: Colors.white,
                            ),
                          ))),
                      onPressed: () {
                        Navigator.pop(context, input);
                      },
                    ),
                  ],
                )
              ],
            )
          ],
        ));
  }

  _buildAlphabets() {
    return Container(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "1",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("1");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "2",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("2");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "3",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("3");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "4",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("4");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "5",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("5");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "6",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("6");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "7",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("7");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "8",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("8");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "9",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("9");
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "0",
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed("0");
                  },
                ),
              ),
            ],
          ),
          Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "Q" : "Q".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "Q" : "Q".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "W" : "W".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "W" : "W".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "E" : "E".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "E" : "E".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "R" : "R".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "R" : "R".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "T" : "T".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "T" : "T".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "Y" : "Y".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "Y" : "Y".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "U" : "U".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "U" : "U".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "I" : "I".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "I" : "I".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "O" : "O".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "O" : "O".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "P" : "P".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "P" : "P".toLowerCase());
                  },
                ),
              ),
            ],
          ),
          Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "A" : "A".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "A" : "A".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "S" : "S".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "S" : "S".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "D" : "D".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "D" : "D".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "F" : "F".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "F" : "F".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "G" : "G".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "G" : "G".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "H" : "H".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "H" : "H".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "J" : "J".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "J" : "J".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "K" : "K".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "K" : "K".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "L" : "L".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "L" : "L".toLowerCase());
                  },
                ),
              ),
            ],
          ),
          Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Container(
                width: MediaQuery.of(context).size.width / 10,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Icon(
                    Icons.file_upload,
                    color: _shifted ? Colors.white : Colors.white.withOpacity(0.4),
                  ),
                  onPressed: () {
                    setState(() {
                      _shifted = !_shifted;
                    });
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "Z" : "Z".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "Z" : "Z".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "X" : "X".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "X" : "X".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "C" : "C".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "C" : "C".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "V" : "V".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "V" : "V".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "B" : "B".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "B" : "B".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "N" : "N".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "N" : "N".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.07,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    _shifted ? "M" : "M".toLowerCase(),
                    style: TextStyle(color: Colors.white, fontSize: 15),
                  ),
                  onPressed: () {
                    numberPressed(_shifted ? "M" : "M".toLowerCase());
                  },
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width / 10,
                margin: EdgeInsets.all(2),
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 1),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Icon(
                    Icons.backspace,
                    color: Colors.white,
                  ),
                  onPressed: () {
                    if (input.length > 0) {
                      setState(() {
                        input = input.substring(0, input.length - 1);
                      });
                    }
                  },
                  onLongPress: () {
                    setState(() {
                      input = "";
                    });
                  },
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  _buildNumpad() {
    return Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: <Widget>[
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "1",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("1");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "2",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("2");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "3",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("3");
                  },
                ),
              ),
            ],
          ),
          SizedBox(
            height: 5,
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: <Widget>[
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "4",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("4");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "5",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("5");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "6",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("6");
                  },
                ),
              ),
            ],
          ),
          SizedBox(
            height: 5,
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: <Widget>[
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "7",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("7");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "8",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("8");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "9",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("9");
                  },
                ),
              ),
            ],
          ),
          SizedBox(
            height: 5,
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: <Widget>[
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    ".",
                    style: TextStyle(color: Colors.white, fontSize: 20),
                  ),
                  onPressed: () {
                    numberPressed(".");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Text(
                    "0",
                    style: TextStyle(color: Colors.white, fontSize: 30),
                  ),
                  onPressed: () {
                    numberPressed("0");
                  },
                ),
              ),
              SizedBox(
                width: 5,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width * 0.24,
                height: MediaQuery.of(context).size.width * 0.15,
                child: RaisedButton(
                  padding: EdgeInsets.symmetric(vertical: 10),
                  shape: RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(10.0),
                  ),
                  color: Colors.grey,
                  child: Icon(
                    Icons.backspace,
                    color: Colors.white,
                  ),
                  onPressed: () {
                    if (input.length > 0) {
                      setState(() {
                        input = input.substring(0, input.length - 1);
                      });
                    }
                  },
                  onLongPress: () {
                    setState(() {
                      input = "";
                    });
                  },
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  numberPressed(String s) {
    if (s == "Clear") {
      setState(() {
        input = "";
      });
    } else if (s == "Cancel") {
      Navigator.pop(context);
    } else {
      setState(() {
        input = input + s;
      });
    }
  }
}
